@@ -184,7 +184,7 @@ class UM7Serial(UM7Registers):
         remainder = sensor_response[next_packet_start_idx:]
         return packet, remainder
 
-    def find_response(self, reg_addr: int, hidden: bool = False) -> Tuple[bool, bytes]:
+    def find_response(self, reg_addr: int, hidden: bool = False, expected_length: int = 7) -> Tuple[bool, bytes]:
         while len(self.buffer) > 0:
             packet, self.buffer = self.find_packet(self.buffer)
             if len(packet) < 4:
@@ -194,7 +194,7 @@ class UM7Serial(UM7Registers):
             packet_type = packet[3]
             is_packet_hidden = bool((packet_type >> 1) & 0x01)
             response_addr = packet[4]
-            if response_addr == reg_addr and hidden == is_packet_hidden:
+            if response_addr == reg_addr and hidden == is_packet_hidden and len(packet) == expected_length:
                 # required packet found
                 return True, packet
         else:
@@ -242,18 +242,18 @@ class UM7Serial(UM7Registers):
         logging.debug(f"packet sent: {packet_to_send}")
         self.send_recv(packet_to_send)
         t = monotonic()
-        ok, sensor_reply = self.find_response(reg_addr, hidden)
+        ok, sensor_reply = self.find_response(reg_addr, hidden, 11)
         if ok:
             logging.debug(f"packet: {sensor_reply}")
             self.check_packet(sensor_reply)
             ok, payload = self.get_payload(sensor_reply)
             return ok, payload
         else:
-            while monotonic() - t < 0.15:
+            while monotonic() - t < 0.2:
                 # try to send <-> receive packets for a pre-defined time out time
                 self.send_recv(packet_to_send)
-                ok, sensor_reply = self.find_response(reg_addr, hidden)
-                if ok:
+                ok, sensor_reply = self.find_response(reg_addr, hidden, 11)
+                if ok and len(sensor_reply) > 7:
                     logging.debug(f"packet: {sensor_reply}")
                     self.check_packet(sensor_reply)
                     ok, payload = self.get_payload(sensor_reply)
@@ -391,84 +391,84 @@ class UM7Serial(UM7Registers):
                     mag_proc_start_addr = self.svd_parser.find_register_by(name='DREG_MAG_PROC_X').address
                     all_raw_start_addr = self.svd_parser.find_register_by(name='DREG_GYRO_RAW_XY').address
                     accel_raw_start_addr = self.svd_parser.find_register_by(name='DREG_ACCEL_RAW_XY').address
-                    mag_raw_start_addr = self.svd_parser.find_register_by(name='DREG_MAG_RAW_X').address
+                    mag_raw_start_addr = self.svd_parser.find_register_by(name='DREG_MAG_RAW_XY').address
                     gyro_bias_start_addr = self.svd_parser.find_register_by(name='DREG_GYRO_BIAS_X').address
                     quat_addr = self.svd_parser.find_register_by(name='DREG_QUAT_AB').address
 
                     if packet_addr == health_start_addr:
                         if len(packet) == 11:
-                            logging.info(f"[HEALTH]: broadcast packet found!")
+                            logging.info("[HEALTH]: broadcast packet found!")
                             yield self.decode_health_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[HEALTH]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == euler_start_addr:
                         if len(packet) == 27:
-                            logging.info(f"[EULER]: broadcast packet found!")
+                            logging.info("[EULER]: broadcast packet found!")
                             yield self.decode_euler_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[EULER]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == all_proc_start_addr:
                         if len(packet) == 55:
-                            logging.info(f"[ALL_PROC]: broadcast packet found!")
+                            logging.info("[ALL_PROC]: broadcast packet found!")
                             yield self.decode_all_proc_broadcast(packet)
                             received_packets += 1
                         elif len(packet) == 23:
-                            logging.info(f"[GYRO_PROC]: broadcast packet found!")
+                            logging.info("[GYRO_PROC]: broadcast packet found!")
                             yield self.decode_proc_gyro_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[GYRO_PROC]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == accel_proc_start_addr:
                         if len(packet) == 23:
-                            logging.info(f"[ACCEL_PROC]: broadcast packet found!")
+                            logging.info("[ACCEL_PROC]: broadcast packet found!")
                             yield self.decode_proc_accel_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[ACCEL_PROC]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == mag_proc_start_addr:
                         if len(packet) == 23:
-                            logging.info(f"[MAG_PROC]: broadcast packet found!")
+                            logging.info("[MAG_PROC]: broadcast packet found!")
                             yield self.decode_proc_mag_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[MAG_PROC]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == all_raw_start_addr:
                         if len(packet) == 51:
-                            logging.info(f"[ALL_RAW]: broadcast packet found!")
+                            logging.info("[ALL_RAW]: broadcast packet found!")
                             yield self.decode_all_raw_broadcast(packet)
                             received_packets += 1
                         elif len(packet) == 19:
-                            logging.info(f"[GYRO_RAW]: broadcast packet found!")
+                            logging.info("[GYRO_RAW]: broadcast packet found!")
                             yield self.decode_raw_gyro_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[GYRO_RAW]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == accel_raw_start_addr:
                         if len(packet) == 19:
-                            logging.info(f"[ACCEL_RAW]: broadcast packet found!")
+                            logging.info("[ACCEL_RAW]: broadcast packet found!")
                             yield self.decode_raw_accel_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[ACCEL_RAW]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == mag_raw_start_addr:
                         if len(packet) == 23:
-                            logging.info(f"[MAG_RAW]: broadcast packet found!")
+                            logging.info("[MAG_RAW]: broadcast packet found!")
                             yield self.decode_raw_mag_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[MAG_RAW]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == quat_addr:
                         if len(packet) == 19:
-                            logging.info(f"[QUAT]: quaternion broadcast packet found!")
+                            logging.info("[QUAT]: quaternion broadcast packet found!")
                             yield self.decode_quaternion_broadcast(packet)
                             received_packets += 1
                         else:
                             logging.error(f"[QUAT]: invalid packet length, got {len(packet)}, packet: {packet}!")
                     elif packet_addr == gyro_bias_start_addr:
                         if len(packet) == 19:
-                            logging.info(f"[GYRO_1_BIAS]: broadcast packet found!")
+                            logging.info("[GYRO_1_BIAS]: broadcast packet found!")
                             yield self.decode_gyro_bias_broadcast(packet)
                             received_packets += 1
                         else:
@@ -523,7 +523,7 @@ class UM7Serial(UM7Registers):
     def decode_raw_gyro_broadcast(self, packet) -> UM7RawGyroPacket:
         payload = packet[5:-2]
         g_x, g_y, g_z, g_time = struct.unpack('>hhh2xf', payload[0:12])
-        return UM7RawGyroPacket(gyro_raw_x=g_x, gyro_raw_y=g_y, gyro_raw_z=g_z,gyro_raw_time=g_time)
+        return UM7RawGyroPacket(gyro_raw_x=g_x, gyro_raw_y=g_y, gyro_raw_z=g_z, gyro_raw_time=g_time)
 
     def decode_raw_mag_broadcast(self, packet) -> UM7RawMagPacket:
         payload = packet[5:-2]
@@ -547,8 +547,8 @@ class UM7Serial(UM7Registers):
 
     def decode_gyro_bias_broadcast(self, packet) -> UM7GyroBiasPacket:
         payload = packet[5:-2]
-        gyro_1_bias_x, gyro_1_bias_y, gyro_1_bias_z, = struct.unpack('>fff', payload[0:12])
-        return UM7GyroBiasPacket(gyro_1_bias_x=gyro_1_bias_x, gyro_1_bias_y=gyro_1_bias_y, gyro_1_bias_z=gyro_1_bias_z)
+        gyro_bias_x, gyro_bias_y, gyro_bias_z, = struct.unpack('>fff', payload[0:12])
+        return UM7GyroBiasPacket(gyro_bias_x=gyro_bias_x, gyro_bias_y=gyro_bias_y, gyro_bias_z=gyro_bias_z)
 
     def decode_health_broadcast(self, packet) -> UM7HealthPacket:
         payload = packet[5:-2]
